@@ -88,7 +88,7 @@ conic_conn_event(ConIcConnection *connection, ConIcConnectionEvent *event)
 
     status = con_ic_connection_event_get_status(event);
 
-    if((_conic_is_connected = (status == CON_IC_CONNECTION_ERROR_NONE)))
+    if((_conic_is_connected = (status == CON_IC_STATUS_CONNECTED)))
     {
         /* We're connected. */
         _conic_conn_failed = FALSE;
@@ -116,7 +116,7 @@ conic_recommend_connected()
 {
     printf("%s()\n", __PRETTY_FUNCTION__);
 
-#ifndef DEBUG
+#ifdef __arm__
     g_mutex_lock(_conic_connection_mutex);
     if(!_conic_is_connecting)
     {
@@ -130,13 +130,13 @@ conic_recommend_connected()
     vprintf("%s(): return\n", __PRETTY_FUNCTION__);
 }
 
-void
+gboolean
 conic_ensure_connected()
 {
     printf("%s()\n", __PRETTY_FUNCTION__);
 
-#ifndef DEBUG
-    while(!_conic_is_connected)
+#ifdef __arm__
+    while(_window && !_conic_is_connected)
     {   
         g_mutex_lock(_conic_connection_mutex);
         /* If we're not connected, and if we're not connecting, and if we're
@@ -150,9 +150,13 @@ conic_ensure_connected()
         g_cond_wait(_conic_connection_cond, _conic_connection_mutex);
         g_mutex_unlock(_conic_connection_mutex);
     }
+#else
+    _conic_is_connected = TRUE;
 #endif
 
-    vprintf("%s(): return\n", __PRETTY_FUNCTION__);
+    vprintf("%s(): return %d\n", __PRETTY_FUNCTION__,
+            _window && _conic_is_connected);
+    return _window && _conic_is_connected;
 }
 
 /**
@@ -180,6 +184,9 @@ maemo_mapper_destroy()
     g_mutex_unlock(_mut_priority_mutex);
 
     /* Allow remaining downloads to finish. */
+    g_mutex_lock(_conic_connection_mutex);
+    g_cond_broadcast(_conic_connection_cond);
+    g_mutex_unlock(_conic_connection_mutex);
     g_thread_pool_free(_mut_thread_pool, TRUE, TRUE);
 
     if(_curr_repo->db)
@@ -322,8 +329,7 @@ maemo_mapper_init(gint argc, gchar **argv)
     /* Set up track array (must be done before config). */
     memset(&_track, 0, sizeof(_track));
     memset(&_route, 0, sizeof(_route));
-    MACRO_PATH_INIT(_track);
-    MACRO_PATH_INIT(_route);
+    /* initialisation of paths is done in path_init() */
 
     _mapdb_mutex = g_mutex_new();
     _mut_priority_mutex = g_mutex_new();
