@@ -107,6 +107,8 @@
 #define GCONF_KEY_CENTER_LAT GCONF_KEY_PREFIX"/center_latitude"
 #define GCONF_KEY_CENTER_LON GCONF_KEY_PREFIX"/center_longitude"
 #define GCONF_KEY_CENTER_ANGLE GCONF_KEY_PREFIX"/center_angle"
+#define GCONF_KEY_MAP_CORRECTION_UNITX GCONF_KEY_PREFIX"/map_correction_unitx"
+#define GCONF_KEY_MAP_CORRECTION_UNITY GCONF_KEY_PREFIX"/map_correction_unity"
 #define GCONF_KEY_ZOOM GCONF_KEY_PREFIX"/zoom"
 #define GCONF_KEY_ROUTEDIR GCONF_KEY_PREFIX"/route_directory"
 #define GCONF_KEY_TRACKFILE GCONF_KEY_PREFIX"/track_file"
@@ -344,6 +346,12 @@ settings_save()
                 GCONF_KEY_CENTER_ANGLE, _map_rotate_angle, NULL);
     }
 
+    /* Save map correction. */
+    gconf_client_set_int(gconf_client,
+            GCONF_KEY_MAP_CORRECTION_UNITX, _map_correction_unitx, NULL);
+    gconf_client_set_int(gconf_client,
+            GCONF_KEY_MAP_CORRECTION_UNITY, _map_correction_unity, NULL);
+
     /* Save last Zoom Level. */
     gconf_client_set_int(gconf_client,
             GCONF_KEY_ZOOM, _zoom, NULL);
@@ -1893,9 +1901,12 @@ settings_init()
                 GCONF_KEY_GPS_RCVR_TYPE, NULL);
         gint i = 0;
         if(gri_type_str)
+        {
             for(i = GPS_RCVR_ENUM_COUNT - 1; i > 0; i--)
                 if(!strcmp(gri_type_str, GPS_RCVR_ENUM_TEXT[i]))
                     break;
+            g_free(gri_type_str);
+        }
         _gri.type = i;
     }
 
@@ -2165,6 +2176,12 @@ settings_init()
         _next_center = _center;
     }
 
+    /* Get map correction.  Default is 0. */
+    _map_correction_unitx = gconf_client_get_int(gconf_client,
+            GCONF_KEY_MAP_CORRECTION_UNITX, NULL);
+    _map_correction_unity = gconf_client_get_int(gconf_client,
+            GCONF_KEY_MAP_CORRECTION_UNITY, NULL);
+
     /* Get last viewing angle.  Default is 0. */
     _map_rotate_angle = _next_map_rotate_angle = gconf_client_get_int(
             gconf_client, GCONF_KEY_CENTER_ANGLE, NULL);
